@@ -119,7 +119,16 @@ class AutoExecutor(Executor):
 
     @classmethod
     def _valid_parameters(cls) -> tp.Set[str]:
-        return {"name", "timeout_min", "mem_gb", "nodes", "cpus_per_task", "gpus_per_node", "tasks_per_node"}
+        return {
+            "name",
+            "timeout_min",
+            "mem_gb",
+            "nodes",
+            "cpus_per_task",
+            "gpus_per_node",
+            "tasks_per_node",
+            "stderr_to_stdout",
+        }
 
     def _internal_update_parameters(self, **kwargs: Any) -> None:
         """Updates submission parameters to srun/crun.
@@ -138,6 +147,8 @@ class AutoExecutor(Executor):
                 - `slurm_time` is used on the slurm cluster
                 - `timeout_min` is used on other clusters
         """
+        # We handle None as not set.
+        kwargs = {k: v for k, v in kwargs.items() if v is not None}
         # check type of replaced variables
         generics = AutoExecutor._valid_parameters()
         for name in generics:
