@@ -47,7 +47,7 @@ class SlurmInfoWatcher(core.InfoWatcher):
         to_check = {x.split("_")[0] for x in self._registered - self._finished}
         if not to_check:
             return None
-        command = ["sacct", "-o", "JobID,State", "--parsable2"]
+        command = ["sacct", "-o", "JobID,State,NodeList", "--parsable2"]
         for jid in to_check:
             command.extend(["-j", str(jid)])
         return command
@@ -341,7 +341,7 @@ class SlurmExecutor(core.PicklingExecutor):
     @property
     def _submitit_command_str(self) -> str:
         return " ".join(
-            [shlex.quote(sys.executable), "-u -m submitit.core._submit", shlex.quote(str(self.folder)),]
+            [shlex.quote(sys.executable), "-u -m submitit.core._submit", shlex.quote(str(self.folder))]
         )
 
     def _make_submission_file_text(self, command: str, uid: str) -> str:
@@ -396,6 +396,7 @@ def _make_sbatch_string(
     num_gpus: tp.Optional[int] = None,  # legacy
     gpus_per_node: tp.Optional[int] = None,
     gpus_per_task: tp.Optional[int] = None,
+    qos: tp.Optional[str] = None,  # quality of service
     setup: tp.Optional[tp.List[str]] = None,
     mem: tp.Optional[str] = None,
     mem_per_gpu: tp.Optional[str] = None,
@@ -408,6 +409,7 @@ def _make_sbatch_string(
     exclusive: tp.Union[bool, str] = False,
     array_parallelism: int = 256,
     wckey: str = "submitit",
+    stderr_to_stdout: bool = False,
     map_count: tp.Optional[int] = None,  # used internally
     additional_parameters: tp.Optional[tp.Dict[str, tp.Any]] = None,
 ) -> str:
@@ -447,11 +449,12 @@ def _make_sbatch_string(
         "array_parallelism",
         "additional_parameters",
         "setup",
+        "signal_delay_s",
+        "stderr_to_stdout",
     ]
-    parameters = {x: y for x, y in locals().items() if y and y is not None and x not in nonslurm}
+    parameters = {k: v for k, v in locals().items() if v and v is not None and k not in nonslurm}
     # rename and reformat parameters
-    parameters["signal"] = signal_delay_s
-    del parameters["signal_delay_s"]
+    parameters["signal"] = f"USR1@{signal_delay_s}"
     if job_name:
         parameters["job_name"] = utils.sanitize(job_name)
     if comment:
@@ -474,25 +477,27 @@ def _make_sbatch_string(
         stdout = stdout.replace("%j", "%A_%a")
         stderr = stderr.replace("%j", "%A_%a")
     parameters["output"] = stdout.replace("%t", "0")
-    parameters["error"] = stderr.replace("%t", "0")
-    parameters.update({"signal": f"USR1@{signal_delay_s}", "open-mode": "append"})
+    if not stderr_to_stdout:
+        parameters["error"] = stderr.replace("%t", "0")
+    parameters["open-mode"] = "append"
     if additional_parameters is not None:
         parameters.update(additional_parameters)
     # now create
     lines = ["#!/bin/bash", "", "# Parameters"]
     lines += [
-        "#SBATCH --{}{}".format(x.replace("_", "-"), "" if parameters[x] is True else f"={parameters[x]}")
-        for x in sorted(parameters)
+        "#SBATCH --{}{}".format(k.replace("_", "-"), "" if parameters[k] is True else f"={parameters[k]}")
+        for k in sorted(parameters)
     ]
     # environment setup:
     if setup is not None:
         lines += ["", "# setup"] + setup
     # commandline (this will run the function and args specified in the file provided as argument)
     # We pass --output and --error here, because the SBATCH command doesn't work as expected with a filename pattern
+    stderr_flag = "" if stderr_to_stdout else f"--error {stderr}"
     lines += [
         "",
         "# command",
         "export SUBMITIT_EXECUTOR=slurm",
-        f"srun --output {stdout} --error {stderr} --unbuffered {command}",
+        f"srun --output {stdout} {stderr_flag} --unbuffered {command}\n",
     ]
     return "\n".join(lines)
