@@ -14,6 +14,8 @@ from unittest.mock import patch
 
 import pytest
 
+import submitit
+
 from .. import helpers
 from ..core import job_environment, submission, test_core, utils
 from ..core.core import Job
@@ -156,9 +158,6 @@ def test_requeuing_checkpointable(tmp_path: Path, fast_forward_clock) -> None:
     sig = get_signal_handler(job)
 
     fast_forward_clock(minutes=30)
-    with mock_requeue(not_called=True):
-        sig.bypass(signal.Signals.SIGTERM)
-
     # Preempt the job after 30 minutes, the job hasn't timeout.
     with pytest.raises(SystemExit), mock_requeue(called_with=1):
         sig.checkpoint_and_try_requeue(signal.Signals.SIGUSR1)
@@ -262,6 +261,11 @@ def test_make_batch_string_gpu() -> None:
     assert "--gpus-per-node=2" in string
 
 
+def test_make_batch_stderr() -> None:
+    string = slurm._make_sbatch_string(command="blublu", folder="/tmp", stderr_to_stdout=True)
+    assert "--error" not in string
+
+
 def test_update_parameters_error() -> None:
     with mocked_slurm() as tmp:
         with pytest.raises(ValueError):
@@ -345,7 +349,7 @@ def test_name() -> None:
 
 
 @contextlib.contextmanager
-def with_slurm_job_nodelist(node_list: str):
+def with_slurm_job_nodelist(node_list: str) -> tp.Iterator[slurm.SlurmJobEnvironment]:
     os.environ["SLURM_JOB_ID"] = "1"
     os.environ["SLURM_JOB_NODELIST"] = node_list
     yield slurm.SlurmJobEnvironment()
@@ -445,7 +449,7 @@ def test_slurm_weird_dir(weird_tmp_path: Path) -> None:
     for l in job.paths.submission_file.read_text().splitlines():
         if not l.startswith("#SBATCH"):
             continue
-        if not "=" in l:
+        if "=" not in l:
             continue
         key, val = l[len("#SBATCH") :].strip().split("=", 1)
         sbatch_args[key] = val.replace("%j", job.job_id).replace("%t", "0")
@@ -454,3 +458,36 @@ def test_slurm_weird_dir(weird_tmp_path: Path) -> None:
     # because we want to check if they have been properly quoted before.
     subprocess.check_call("ls " + sbatch_args["--output"], shell=True)
     subprocess.check_call("ls " + sbatch_args["--error"], shell=True)
+
+
+@pytest.mark.parametrize("params", [{}, {"mem_gb": None}])  # type: ignore
+def test_slurm_through_auto(params: tp.Dict[str, int], tmp_path: Path) -> None:
+    with mocked_slurm():
+        executor = submitit.AutoExecutor(folder=tmp_path)
+        executor.update_parameters(**params, slurm_additional_parameters={"mem_per_gpu": 12})
+        job = executor.submit(test_core.do_nothing, 1, 2, blublu=3)
+    text = job.paths.submission_file.read_text()
+    mem_lines = [x for x in text.splitlines() if "#SBATCH --mem" in x]
+    assert len(mem_lines) == 1, f"Unexpected lines: {mem_lines}"
+
+
+def test_slurm_job_no_stderr() -> None:
+    def fail_silently():
+        raise ValueError("Too bad")
+
+    with mocked_slurm() as tmp:
+        executor = slurm.SlurmExecutor(folder=tmp)
+        # Failed but no stderr
+        job = executor.submit(fail_silently)
+        _mock_log_files(job, prints="job is running ...\n")
+        job._results_timeout_s = 0
+        with pytest.raises(utils.UncompletedJobError, match="job is running ..."):
+            job._get_outcome_and_result()
+
+        # Failed but no stderr nor stdout
+        job = executor.submit(fail_silently)
+        job._results_timeout_s = 0
+        # Explicitly unlink stdout because submitit is writing there on startup
+        job.paths.stdout.unlink()
+        with pytest.raises(utils.UncompletedJobError, match="No output/error stream produced !"):
+            job._get_outcome_and_result()
